Package: CarletonStats
Title: Functions for Statistics Classes at Carleton College
Version: 2.3
Authors@R: c(
  person("Laura", "Chihara" , email = "flchihara@carleton.edu", role = c("aut")),
  person("Adam", "Loy", email = "aloy@carleton.edu", role = c("aut", "cre"), 
    comment = c(ORCID = "0000-0002-5780-4611"))
   )
Description: Includes commands for bootstrapping and permutation tests, a
    command for created grouped bar plots, and a demo of the
    quantile-normal plot for data drawn from different distributions.
Depends: R (>= 3.5.0)
License: GPL-2
URL: https://github.com/aloy/CarletonStats
BugReports: https://github.com/aloy/CarletonStats/issues
Suggests: grDevices, MASS, testthat (>= 3.0.0)
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: TRUE
NeedsCompilation: no
RoxygenNote: 8.0.0
Imports: ggplot2 (>= 3.3.0), scales, patchwork
Packaged: 2026-08-28 14:25:31 UTC; aloy
Author: Laura Chihara [aut],
  Adam Loy [aut, cre] (ORCID: <https://orcid.org/0000-0002-5780-4611>)
Maintainer: Adam Loy <aloy@carleton.edu>
Repository: CRAN
Date/Publication: 2026-08-28 17:00:16 UTC
