# Generated by roxygen2: do not edit by hand

S3method(boot,default)
S3method(boot,formula)
S3method(bootCor,default)
S3method(bootCor,formula)
S3method(bootPaired,default)
S3method(bootPaired,formula)
S3method(bootSlope,default)
S3method(bootSlope,formula)
S3method(confint,carlboot)
S3method(groupedBar,default)
S3method(groupedBar,formula)
S3method(permTest,default)
S3method(permTest,formula)
S3method(permTestAnova,default)
S3method(permTestAnova,formula)
S3method(permTestCor,default)
S3method(permTestCor,formula)
S3method(permTestPaired,default)
S3method(permTestPaired,formula)
S3method(permTestSlope,default)
S3method(permTestSlope,formula)
S3method(plot,carlboot)
S3method(plot,carlperm)
S3method(print,carlboot)
S3method(print,carlperm)
S3method(stemPlot,default)
S3method(stemPlot,formula)
S3method(summary,carlboot)
S3method(summary,carlperm)
export(anovaSummarized)
export(boot)
export(bootCor)
export(bootPaired)
export(bootSlope)
export(confIntDemo)
export(corDemo)
export(groupedBar)
export(missingLevel)
export(permTest)
export(permTestAnova)
export(permTestCor)
export(permTestPaired)
export(permTestSlope)
export(qqPlotDemo)
export(stemPlot)
import(ggplot2)
importFrom(grDevices,dev.new)
importFrom(graphics,abline)
importFrom(graphics,hist)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,stem)
importFrom(graphics,title)
importFrom(patchwork,wrap_plots)
importFrom(scales,label_percent)
importFrom(stats,aov)
importFrom(stats,complete.cases)
importFrom(stats,confint)
importFrom(stats,cor)
importFrom(stats,density)
importFrom(stats,pf)
importFrom(stats,qnorm)
importFrom(stats,qqline)
importFrom(stats,qqnorm)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,rbeta)
importFrom(stats,rbinom)
importFrom(stats,rchisq)
importFrom(stats,rexp)
importFrom(stats,rf)
importFrom(stats,rnorm)
importFrom(stats,rt)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,terms)
