
<!-- badges: start -->

[![R-CMD-check](https://github.com/aloy/CarletonStats/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/aloy/CarletonStats/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

# CarletonStats

<!-- badges: start -->

<!-- badges: end -->

The **CarletonStats** package includes commands for bootstrapping and
permutation tests used in Stat 120 at Carleton College. Additional
commands of interest include a command for creating grouped bar plots,
and a demo of the quantile-normal plot for data drawn from different
distributions.

## Installation

You can install the development version of CarletonStats from
[GitHub](https://github.com/) with:

``` r
# install.packages("devtools")
devtools::install_github("aloy/CarletonStats")
```
